@@ -141,7 +141,7 @@ class HTTPInternal(HTTPError):
 
 
 def log_exception(log, message, exception, level=logging.WARNING):
-    log.log(level, f"{message}: {exception}", exc_info="exception" in mini_buildd.config.DEBUG)
+    log.log(level, f"{message}: {exception}", exc_info=log.isEnabledFor(logging.DEBUG))
 
 
 def log_stack(log, level=logging.INFO):
