@@ -33,7 +33,6 @@ class Uploader(mini_buildd.threads.EventThread):
         with self.lock:
             try:
                 event.upload(mini_buildd.net.ClientEndpoint(event.cget("Upload-To"), protocol="ftp"))
-                mini_buildd.get_daemon().events.log(mini_buildd.events.Type.BUILT, event)
                 self.failed.pop(event.bkey, None)
             except BaseException as e:
                 mini_buildd.log_exception(LOG, f"Upload to {event.cget('Upload-To')} failed (will retry)", e)
@@ -87,6 +86,7 @@ class Build(mini_buildd.threads.DeferredThread):
             self.bres.cset("Internal-Error", str(mini_buildd.e2http(e)))
             self.bres.save_to(self.bres.builds_path)
 
+        mini_buildd.get_daemon().events.log(mini_buildd.events.Type.BUILT, self.bres)
         self.uploader_queue.put(self.bres)
 
 
