@@ -60,9 +60,11 @@ class Css():
             "REMOVED": NOTICE,
         },
         "model_status": {
-            "Removed": ERROR,
-            "Prepared": NOTICE,
-            "Active": SUCCESS,
+            "None": ERROR,       # Non-existing object
+            "Exists": INFO,      # Existing (non StatusModel) object
+            "Removed": WARNING,  # Removed StatusModel object
+            "Prepared": NOTICE,  # Prepared StatusModel object
+            "Active": SUCCESS,   # Active StatusModel object
         },
         "django_messages": {
             "debug": INFO,
@@ -188,14 +190,16 @@ def mbd_accounts(context, url_name, name=None, title=None, nxt=None, cls=""):
 
 @register.inclusion_tag("mini_buildd/includes/tags/api.html", takes_context=True)
 def mbd_api(context, call, name=None, hide_options=False, verbose=False, **kwargs):
+    prefix = "value_"
+    api_args = {k[len(prefix):]: v for k, v in kwargs.items() if k.startswith(prefix)}
     if isinstance(call, str):
         api_cls = mini_buildd.api.CALLS.get(call)
         if api_cls is None:
             raise mini_buildd.HTTPBadRequest(f"Unknown API call: {name}")
-        prefix = "value_"
-        api_call = api_cls(**{k[len(prefix):]: v for k, v in kwargs.items() if k.startswith(prefix)})
+        api_call = api_cls(**api_args)
     else:
         api_call = call
+        api_call.set_args(**api_args)
 
     args = {"mandatory": [], "optional": [], "hidden": []}
     for arg in api_call.args.values():
