@@ -457,7 +457,7 @@ class Upload(Changes):
 
             buildrequest.cset("Buildlog", os.path.join(buildrequest.bkey, self.dfn.buildlog(ao.architecture.name)))
 
-            builders = mini_buildd.mdls().gnupg.Builders(check=True).get(self.dist.codename, ao.architecture.name)
+            builders = mini_buildd.mdls().gnupg.Builders(wake=True, check=True).get(self.dist.codename, ao.architecture.name)
             for _load, builder in sorted(builders.items()):
                 try:
                     buildrequest.cset("Builder", builder["url"])
