@@ -132,7 +132,7 @@ class CLI():
         self.parser = argparse.ArgumentParser(prog=prog, description=description, epilog=epilog,
                                               formatter_class=ArgumentDefaultsRawTextHelpFormatter)
         self.parser.add_argument("--version", action="version", version=mini_buildd.__version__)
-        self.parser.add_argument("-l", "--log-level", choices=LOG_LEVELS.keys(), action="store", default="INFO", help="set log level")
+        self.parser.add_argument("-l", "--log-level", choices=LOG_LEVELS.keys(), action="store", default="INFO", help="set log level (DEBUG will enable exception tracebacks and python warnings)")
         self.parser.add_argument("-v", "--verbose", dest="verbosity", action="count", default=0,
                                  help="DEPRECATED (use --log-level): increase log level. Give twice for max logs")
         self.parser.add_argument("-q", "--quiet", dest="terseness", action="count", default=0,
@@ -181,10 +181,10 @@ class CLI():
 
         self.logger.setLevel(self.args.log_level)
         self.wlogger.setLevel(self.args.log_level)
-        logging.captureWarnings(True)
+        logging.captureWarnings(self.logger.isEnabledFor(logging.DEBUG))
         if not sys.warnoptions:
             warnings.simplefilter("default")
-        logging.raiseExceptions = "exception" in mini_buildd.config.DEBUG  # Properly set raiseException based "exception" debug value given (see https://docs.python.org/3.5/howto/logging.html#exceptions-raised-during-logging)
+        logging.raiseExceptions = self.logger.isEnabledFor(logging.DEBUG)  # Properly set raiseException (see https://docs.python.org/3.5/howto/logging.html#exceptions-raised-during-logging)
 
         try:
             self.runcli()
