@@ -145,8 +145,8 @@ class Daemon(mini_buildd.threads.PollerThread, metaclass=mini_buildd.misc.Single
 
 
 class Stopped():
-    def __init__(self, force_start=False):
-        self.start = force_start or mini_buildd.get_daemon().is_alive()
+    def __init__(self):
+        self.start = mini_buildd.get_daemon().is_alive()
 
     def __enter__(self):
         mini_buildd.get_daemon().mbd_stop()
