@@ -19,7 +19,7 @@ import distro_info
 import debian.debian_support
 
 import mini_buildd
-from mini_buildd import sbuild
+from mini_buildd import sbuild, misc
 
 LOG = logging.getLogger(__name__)
 
@@ -231,7 +231,6 @@ SETUP = {
                     "apt_keys": [APT_KEYS["Debian"]["buster"]["archive"], APT_KEYS["Debian"]["bullseye"]["archive"]],
                     "sources": {
                         "sid": {},
-                        "experimental": {},
                     },
                 },
                 "bookworm": {
@@ -711,36 +710,43 @@ SETUP = {
             }
         },
     },
-    "repository": {
-        "default": {
-            "layout": "Default",
-            "distribution_filter": {
-                "base_source__codename__regex": ".*",
-            },
-        },
-        "test": {
-            "layout": "Default",
-            "distribution_filter": {
-                "base_source__codename__regex": ".*",
-            },
-            "options": {
-                "allow_unauthenticated_uploads": True,
-            },
-        },
-        "debdev": {
-            "layout": "Debian Developer",
-            "distribution_filter": {
-                "base_source__codename": "sid",
-            },
-            "options": {
-                "extra_uploader_keyrings": ("# Allow Debian maintainers (must install the 'debian-keyring' package)\n"
-                                            "/usr/share/keyrings/debian-keyring.gpg"),
-            },
-        },
-    },
 }
 
 
+def setup_origins():
+    return SETUP["origin"].keys()
+
+
+def setup_codenames():
+    codenames = []
+    for o in setup_origins():
+        codenames.extend(SETUP["origin"][o]["codename"])
+    return codenames
+
+
+VENDOR_CODENAMES_FUNC = {
+    "": lambda origin: [codename for codename in DISTRO_INFO[origin].supported() if codename in setup_codenames()],
+    "lts": lambda origin: [codename for codename in DISTRO_INFO[origin].supported() + DISTRO_INFO[origin].mbd_lts() if codename in setup_codenames()],
+    "all": lambda origin: [codename for codename, setup in SETUP["origin"][origin]["codename"].items() if setup.get("broken") is None],
+}
+
+
+def setup_codenames_from_origin(origin, modifier=""):
+    try:
+        return VENDOR_CODENAMES_FUNC[modifier](origin)
+    except KeyError as e:
+        raise mini_buildd.HTTPBadRequest(f"Unknown codenames selector: '{origin}:{modifier}' (use '{'|'.join(setup_origins())}[:{'|'.join(VENDOR_CODENAMES_FUNC.keys())}]'") from e
+
+
+def _idi_codenames():
+    for di in DISTRO_INFO.values():
+        yield from di.all
+
+
+def di_codenames():
+    return list(_idi_codenames())
+
+
 def guess_origin(codename):
     """
     Guess Origin from codename
@@ -763,6 +769,11 @@ def guess_origin(codename):
     return None
 
 
+def is_base_source(origin, codename):
+    """Heuristics (for setup) whether this is a base source"""
+    return origin in mini_buildd.dist.SETUP["origin"] and re.match(r"^[a-z]+$", codename) and codename != "experimental"
+
+
 #: List of Debian codenames using something ``3.1`` as main version (all <= squeeze)
 DEBIAN_MAJOR_MINOR_CODENAMES = ["buzz", "rex", "bo", "hamm", "slink", "potato", "woody", "sarge", "etch", "lenny", "squeeze"]
 
@@ -837,6 +848,85 @@ class Codename():
         if di is not None:
             self.cmpversion = di.mbd_cmpversion(self.codename, self.codeversion)
 
+        self.setup = SETUP["origin"].get(self.origin, {}).get("codename", {}).get(self.codename)
+        self.has_setup = self.setup is not None
+        if not self.has_setup:
+            self.setup = self._default_setup()
+
+    def _default_setup(self):
+        if self.origin == "Debian":
+            return {
+                "sources": {
+                    self.codename: {},
+                    f"{self.codename}-security": {
+                        "options": {
+                            "extra_options": "X-Remove-From-Component: updates/",
+                        },
+                    },
+                    f"{self.codename}-backports": {
+                        "origin": "Debian Backports",
+                    },
+                }
+            }
+        if self.origin == "Ubuntu":
+            return {
+                "apt_keys": [APT_KEYS["Ubuntu"]["2018"]],
+                "sources": {
+                    self.codename: {},
+                    f"{self.codename}-security": {
+                        "options": {
+                            "extra_options": f"Codename: {self.codename}\nSuite: {self.codename}-security",
+                        },
+                    },
+                    f"{self.codename}-backports": {
+                        "options": {
+                            "extra_options": f"Codename: {self.codename}\nSuite: {self.codename}-backports",
+                        },
+                    },
+                },
+                "distribution": {
+                    "options": {
+                        "extra_options": sbuild.CONFIG_BLOCKS.default() + "\n" + sbuild.SETUP_BLOCKS.default() + "\nDeb-Build-Options: noddebs",
+                    },
+                    "arch_optional": ["i386"],
+                }
+            }
+        return {}
+
+    def setup_lintian_options(self, kind):
+        """
+        Get lintian options from SETUP.
+        """
+        return misc.mdget(self.setup, ["lintian_options", kind], SETUP["lintian_options"][kind])
+
+    def setup_sources(self):
+        return self.setup.get("sources", {}).keys()
+
+    def setup_origin(self, source_codename):
+        return misc.mdget(self.setup, ["sources", source_codename, "origin"], self.origin)
+
+    def setup_apt_keys(self, source_codename):
+        return misc.mdget(self.setup, ["sources", source_codename, "apt_keys"], self.setup.get("apt_keys", []))
+
+    def setup_options(self, source_codename):
+        return misc.mdget(self.setup, ["sources", source_codename, "options"], {})
+
+    def setup_distribution_options(self):
+        return misc.mdget(self.setup, ["distribution", "options"], {})
+
+    def setup_chroot_options(self):
+        return misc.mdget(self.setup, ["chroot", "options"], {})
+
+    def setup_is_security(self, source_codename):
+        regex = misc.mdget(SETUP, ["origin", self.origin, "security_codename_regex"])
+        return regex is not None and regex.match(source_codename)
+
+    def setup_arch_optional(self):
+        return misc.mdget(self.setup, ["distribution", "arch_optional"], [])
+
+    def setup_components(self):
+        return misc.mdget(SETUP, ["origin", self.origin, "default_components"], ["main"])
+
     def __str__(self):
         return f"{self.origin} '{self.codename}' ({self.codeversion})"
 
@@ -856,45 +946,6 @@ class Codename():
         return NotImplemented
 
 
-class Codenames(dict):
-    def __init__(self):
-        super().__init__()
-        for origin, origin_setup in SETUP["origin"].items():
-            for codename, setup in origin_setup["codename"].items():
-                self[codename] = setup
-                self[codename]["origin"] = origin  # Convenience
-
-    def get_supported(self, origin):
-        di = DISTRO_INFO[origin]
-        return [codename for codename in di.supported() if codename in self]
-
-    def get_supported_plus_lts(self, origin):
-        di = DISTRO_INFO[origin]
-        return [codename for codename in di.supported() + di.mbd_lts() if codename in self]
-
-    @classmethod
-    def get_working(cls, origin):
-        return [codename for codename, setup in SETUP["origin"][origin]["codename"].items() if setup.get("broken") is None]
-
-    @classmethod
-    def is_security(cls, origin, codename):
-        origin_setup = SETUP["origin"].get(origin)
-        return origin_setup is not None and origin_setup["security_codename_regex"].match(codename)
-
-    def get_lintian_options(self, codename, kind):
-        """
-        Get lintian options from SETUP.
-        """
-        try:
-            return self[codename]["lintian_options"][kind]
-        except KeyError as e:
-            LOG.debug(f"lintian options for {codename}/{kind}: Using defaults (key: {e})")
-            return SETUP["lintian_options"][kind]
-
-
-CODENAMES = Codenames()
-
-
 class SbuildCheck():
     """
     Generic support for sbuild checks (lintian, piuparts, autopkgtest).
@@ -964,9 +1015,10 @@ class SbuildCheck():
             (status in self.STATUSES_WARN and self.mode is not self.Mode.WARNFAIL)
 
     def lintian_options(self, codename):
-        options = CODENAMES.get_lintian_options(codename, "common")
+        _codename = Codename(codename)
+        options = _codename.setup_lintian_options("common")
         if self.mode == self.Mode.WARNFAIL:
-            options += CODENAMES.get_lintian_options(codename, "warnfail")
+            options += _codename.setup_lintian_options("warnfail")
         return mini_buildd.PyCompat.shlex_join(options)
 
 
@@ -1047,3 +1099,10 @@ if __name__ == "__main__":
     for DI in [DebianDistroInfo(), UbuntuDistroInfo()]:
         for C in DI.all:
             print(Codename(C))
+    print(setup_origins())
+    print(setup_codenames())
+    print(setup_codenames_from_origin("Debian"))
+    print(setup_codenames_from_origin("Debian", "all"))
+    print(setup_codenames_from_origin("Debian", "lts"))
+    print(di_codenames())
+    print(setup_codenames_from_origin("Debian", "qual"))
