@@ -80,7 +80,7 @@ def get_django_secret_key(home):
 
 def configure(smtp_string):
     """Configure django."""
-    LOG.info("Setting up django...")
+    LOG.debug("Setting up django...")
 
     smtp = SMTPCreds(smtp_string)
     debug = "webapp" in mini_buildd.config.DEBUG
