@@ -6,7 +6,6 @@ import datetime
 import glob
 import json
 import threading
-import itertools
 import collections
 import functools
 import weakref
@@ -58,9 +57,6 @@ class Event():
         self.timestamp = mini_buildd.misc.Datetime.now()
         self.extra = extra
 
-        #: Special run-time only flag (see Events.log()). For events outside Events(), this will always be false.
-        self.ongoing = False
-
     def strerror(self):
         """Public human-readable one-liner string from ``extra.error``."""
         error = self.extra.get("error")  # Rfc7807 dict
@@ -139,6 +135,13 @@ class Event():
         with mini_buildd.fopen(file_path) as f:
             return Event.from_json(json.load(f))
 
+    def ongoing(self):
+        """Get ongoing status (bool) -- convenience for template access"""
+        try:
+            return self.extra["bkey"] in mini_buildd.get_daemon().events.ongoing
+        except Exception:
+            return False
+
 
 class Queue(collections.deque):
     def __init__(self, *args, **kwargs):
@@ -168,12 +171,9 @@ class Queue(collections.deque):
             if event.type in [Type.PACKAGING, Type.BUILDING]:
                 LOG.debug(f"Adding event to 'ongoing': {changes.bkey}={event}")
                 self.ongoing[changes.bkey] = event
-                event.ongoing = True
             elif event.type in [Type.BUILT, Type.INSTALLED, Type.FAILED]:
                 LOG.debug(f"Deleting event from 'ongoing': {changes.bkey} from {event}")
-                ongoing_event = self.ongoing.pop(changes.bkey, None)   # None: Should rather not raise exception here if key is not there for some reason
-                if ongoing_event is not None:
-                    ongoing_event.ongoing = False
+                self.ongoing.pop(changes.bkey, None)   # None: Should rather not raise exception here if key is not there for some reason
 
     def attach(self, obj, after=None):
         with self._lock:
@@ -216,11 +216,6 @@ class Queue(collections.deque):
     def load(cls, maxlen):
         return Queue(load(maxlen=maxlen), maxlen=maxlen)
 
-    def mbd_slice(self, maxlen=None):
-        """Return triple: <list of newest events>, <total number of events in queue>, <max number of events in queue>, <number of ongoing>."""
-        with self._lock:
-            return list(itertools.islice(self, maxlen)), len(self), self.maxlen, len(self.ongoing)
-
 
 class Attach():
     def __init__(self, events, *args, **kwargs):
