@@ -143,10 +143,16 @@ class Events(twisted.web.resource.Resource):
 
           Retests with ``twisted 22.2`` could not (yet) reproduce this behaviour. So I guess it would be fine
           to remove this once we can pimp the dependency in ``debian/control``.
+
+          Retests with ``twisted 22.4`` occasionally also showed (twisted: "Timing out client"), so I added
+          ``setTimeout(None)`` as well. I.e., I had no such failures with that workaround, however I also had some
+          *successful* testsuite runs w/o that workaround.
         """
         what = cls.mbd_ssl_workaround.__doc__.splitlines()[1].strip()
         try:
+            LOG.debug(f"{request.channel}: PRE: timeOut={request.channel.timeOut}, abortTimeout={request.channel.abortTimeout}")
             request.channel.abortTimeout = None
+            request.channel.setTimeout(None)
             LOG.warning(f"{request.channel}: {what}: Disabled 'abortTimeout' (timeOut={request.channel.timeOut}, abortTimeout={request.channel.abortTimeout}).")
         except BaseException as e:
             mini_buildd.log_exception(LOG, what, e)
