@@ -31,6 +31,48 @@ def singularize(s):
     return s
 
 
+def esplit(s, sep):
+    """Unlike python ``str.strip(sep)``, this delivers an empty list for the empty string."""
+    return [] if s == "" else s.split(sep)
+
+
+def uniq(iterable):
+    """
+    Make list unique
+
+    Sometimes, a ``list`` should be unique, but you don't want to use ``set`` (for example, as it does not keep order or
+    can't be JSON-serialized).
+
+    There does not seem to be a simple builtin for this. Since ``python 3.7``, ``dict`` is guaranteed to be ordered, so
+    we can use this approach.
+    """
+    return list(dict.fromkeys(iterable).keys())
+
+
+def mdget(d, keys, default=None):
+    """
+    Get nested value from multidimensional dict, return default if any 'path part' is missing.
+
+    Rather use this instead of code like ``d.get(foo, {}).get(bar, {}).get(mykey, mydefaultvalue)``.
+
+    >>> d = {"foo": {"bar": {"mykey": "myvalue"}}}
+    >>> mdget(d, ["foo", "bar", "mykey"], "default_value")
+    'myvalue'
+    >>> mdget(d, ["fpp", "bar", "mykey"], "default_value")
+    'default_value'
+    >>> mdget(d, ["foo", "bsr", "mykey"], "default_value")
+    'default_value'
+    >>> mdget(d, ["foo", "bar", "mykex"], "default_value")
+    'default_value'
+    """
+    _d = d
+    for k in keys:
+        _d = _d.get(k)
+        if _d is None:
+            return default
+    return _d
+
+
 class Datetime:
     """Datetime tools -- always use same/comparable (aware && UTC) datetime objects."""
 
