@@ -72,7 +72,7 @@ Debootstrap-Extra-Options: <EXTRA_OPTIONS>: Additional debootrap options
         return f"{self.source.codename}:{self.architecture.name}"
 
     def __str__(self):
-        return f"{self.source.origin} '{self.mbd_key()}'"
+        return f"{self.__class__.__name__} for {self.source} with {self.architecture}"
 
     @property
     def mbd_path(self):
