@@ -22,16 +22,6 @@ LOG = logging.getLogger(__name__)
 
 
 class Daemon(mini_buildd.models.base.StatusModel):
-    MBD_HELP_PICKLED_DATA = """\
-Saved ``setup`` config as command line options. See ``mini-buildd-api setup --help`` for syntax.
-
-You may set values manually here, or just use ``save=True`` in an any call to ``setup``, either from the command line or web application.
-
-A setup command preconfigured with these values will be available from the ``setup`` page.
-
-Note: In case you see a base64 dump, just remove it. It's a now unused leftover from 1.0.x usage of this field (and no good way to avoid it completely).
-"""
-
     MBD_HELP_EXTRA_OPTIONS = """
 X-Archive-Origin: <origin>
   Custom APT "Origin" field for repository indices.
@@ -153,10 +143,6 @@ maintainers to be accidentally spammed.
 
         filter_horizontal = ("notify",)
 
-        @classmethod
-        def _mbd_on_activation(cls, obj):
-            mini_buildd.get_daemon().mbd_start()
-
         @classmethod
         def _mbd_on_deactivation(cls, obj):
             mini_buildd.get_daemon().mbd_stop()
@@ -171,30 +157,6 @@ maintainers to be accidentally spammed.
                 f"entertaining {len(mini_buildd.models.chroot.Chroot.mbd_get_active())} chroots, "
                 f"using {len(mini_buildd.models.gnupg.Remote.mbd_get_active())} remotes")
 
-    def mbd_setup_v10x2v20x(self):
-        """
-        Fixup v10x->v20x 'pickled_data' is now 'setup' upgrade convenience.
-
-        Arbitrary heuristic number to decide whether the data is actually still pickled data from 1.0.x, and should be automatically blanked:
-         - Typical 1.0.x "last packages" pickled size: 200000
-         - A rather lengthy (but still real life) setup may have about: 2000
-
-         This practically limits the possible setup command line length for the convenience save.
-        """
-        max_setup_len = 4000
-        if len(self.pickled_data) > max_setup_len:
-            LOG.warning(f"Setup length ({len(self.pickled_data)}) exceeds max setup length ({max_setup_len}): Setting blank (assuming pickled data from 1.0.x)")
-            self.mbd_setup_save("")
-
-    def mbd_setup_save(self, command_line):
-        """Save setup command line."""
-        LOG.debug(f"Saving setup: {command_line}")
-        self.pickled_data = command_line
-        self.save(update_fields=["pickled_data"])
-
-    def mbd_setup_get(self):
-        return self.pickled_data
-
     def mbd_get_ftp_endpoint(self):
         return mini_buildd.net.ServerEndpoint(self.ftpd_bind, protocol="ftp")
 
@@ -218,7 +180,7 @@ maintainers to be accidentally spammed.
         except BaseException as e:
             raise django.core.exceptions.ValidationError({"ftpd_bind": f"Can't parse '{self.ftpd_bind}': {mini_buildd.e2http(e)}"})
 
-        if Daemon.objects.count() > 0 and self.id != Daemon.objects.get().id:
+        if Daemon.objects.count() > 0 and self.pk != Daemon.objects.get().pk:
             raise django.core.exceptions.ValidationError("You can only create one Daemon instance!")
 
     def mbd_prepare(self):
@@ -348,6 +310,4 @@ def get():
     model, created = mini_buildd.models.daemon.Daemon.objects.get_or_create(id=1, defaults={"ftpd_bind": mini_buildd.config.default_ftp_endpoint()})
     if created:
         LOG.info("New Daemon model instance created")
-    else:
-        model.mbd_setup_v10x2v20x()
     return model
