@@ -344,7 +344,15 @@ $build_environment = { 'MY_FOO_BAR' => '%LIBDIR%/my-foo-bar' };
         return True
 
     def __str__(self):
-        return f"Distribution for {self.base_source}"
+        """
+         Note: Appends 'id' only to make multiple Distributions for same base source distinguishable for the user
+
+        .. attention:: Distributions are not unique for base source (historic fluke).
+        """
+        return f"Distribution for {self.base_source} [pk={self.pk}]"
+
+    def mbd_setup(self):
+        return f"{self.base_source.codename}:{'+'.join((a.name for a in self.architectures.all()))}"
 
     def mbd_get_components(self):
         return [c.name for c in sorted(self.components.all())]
