@@ -54,6 +54,7 @@ class GnuPGPublicKey(mini_buildd.models.base.StatusModel):
     def mbd_prepare(self):
         key, info = mini_buildd.gnupg.PublicKeyCache().keyinfo(self.key_id, self.key)
         self.key, self.key_long_id, self.key_name, self.key_fingerprint, self.key_created, self.key_expires = key, info["key"], info["user"], info["fingerprints"][0], info["created"], info["expires"]
+        self.key_id = self.key_long_id
 
     def mbd_remove(self):
         self.key_long_id = ""
@@ -83,7 +84,7 @@ class AptKey(GnuPGPublicKey):
 
         if self.key_id:
             matching_key = self.mbd_filter_key(self.key_id)
-            if matching_key.count() > 0 and self.id != matching_key.get().id:
+            if matching_key.count() > 0 and self.pk != matching_key.get().pk:
                 raise django.core.exceptions.ValidationError({"key_id": f"Another such key id already exists: {matching_key[0]}"})
 
 
@@ -190,8 +191,8 @@ class Remote(KeyringKey):
         """Check whether the remote mini-buildd is up, running and serving for us."""
         super().mbd_check()
 
-        # Get status, wake if needed
-        status = self.mbd_get_status(wake=True)
+        # Get status
+        status = self.mbd_get_status()
 
         # GnuPG handshake
         signed_message = self.mbd_api(Handshake(signed_message=mini_buildd.get_daemon().handshake_message()))
@@ -199,32 +200,39 @@ class Remote(KeyringKey):
 
         # Check if our instance is activated on remote
         if mini_buildd.http_endpoint().geturl() not in status["remotes"]:
-            raise mini_buildd.HTTPBadRequest(f"{self}: Seems to be deactivated on remote instance.")
+            raise mini_buildd.HTTPBadRequest(f"{self}: Our instance is not activated on remote.")
 
         # Check if our instance is powered on
         if status["load"] < 0.0:
             raise mini_buildd.HTTPBadRequest(f"{self}: Remote is powered off.")
 
 
-Builder = collections.namedtuple("Builder", "remote status exception ourselves")
-
-
 class Builders(list):
-    def __init__(self, check=False):
-        super().__init__()
-        self.add(Remote(http=mini_buildd.http_endpoint().geturl(), status=Remote.STATUS_ACTIVE, last_checked=django.utils.timezone.now()), ourselves=True)
-        for r in Remote.objects.all():
-            self.add(r, check=check)
+    """
+    All builders (ourselves as Meta-Remote plus all actual Remotes) with status
 
-    def add(self, r, ourselves=False, check=False):
-        try:
-            if check:
-                r.mbd_check(force=True)
-            status = r.mbd_get_status()
-            self.append(Builder(r, status, None, ourselves))
-        except BaseException as e:
-            LOG.warning(f"{r}: {e}")
-            self.append(Builder(r, None, mini_buildd.e2http(e), ourselves))
+    Is used to choose builder to upload to, and as data for the Builder's View.
+    """
+
+    Builder = collections.namedtuple("Builder", "remote status exception ourselves")
+
+    def __init__(self, wake=False, check=False):
+        super().__init__()
+
+        # Always add ourselves
+        ourselves = Remote(http=mini_buildd.http_endpoint().geturl(), status=Remote.STATUS_ACTIVE, last_checked=django.utils.timezone.now())
+        self.append(Builders.Builder(ourselves, ourselves.mbd_get_status(), None, True))
+
+        for r in Remote.objects.all():
+            status, exception = None, None
+            try:
+                status = r.mbd_get_status(wake=wake)
+                if check:
+                    Remote.Admin.mbd_check(r, force=True)
+            except BaseException as e:
+                exception = mini_buildd.e2http(e)
+            finally:
+                self.append(Builders.Builder(r, status, exception, False))
 
     def get(self, codename, arch):
         """Get a dict {<load>: <status>} of active builders for <codename>/<arch>."""
