@@ -96,6 +96,9 @@ Example:
     def __str__(self):
         return f"Repository '{self.identity}' with distributions for {','.join([d.base_source.codename + ('' if d.mbd_is_active() else '*') for d in self.mbd_sorted_distributions()])}"
 
+    def mbd_setup(self):
+        return f"{self.identity}:{self.layout.name}:{'+'.join((d.base_source.codename for d in self.distributions.all()))}"
+
     def mbd_json(self):
         return {
             "codenames": [d.base_source.codename for d in self.distributions.all()],
@@ -348,11 +351,11 @@ Example:
                 raise mini_buildd.HTTPBadRequest(f"You can't migrate from '{src_diststr}'")
             dst_diststr = self.mbd_get_diststr(distribution, suite.migrates_to)
 
-            # Check if package is in src_dst
-            pkg_ls.filter(diststr=src_diststr, version=version, raise_if_not_found="No such source")
+            # Check if package is in src_dst (&& update 'version' if None)
+            version = pkg_ls.filter(diststr=src_diststr, version=version, raise_if_not_found="No such source")[src_diststr]["version"]
 
             # Check that version is not already migrated
-            if version is not None and pkg_ls.filter(diststr=dst_diststr, version=version):
+            if pkg_ls.filter(diststr=dst_diststr, version=version):
                 raise mini_buildd.HTTPBadRequest(f"Version '{version}' already migrated to '{dst_diststr}'")
 
             # Shift rollbacks in the destination distributions
