@@ -43,7 +43,7 @@ Use the 'directory' notation with exactly one trailing slash (like 'http://examp
         search_fields = ["url"]
 
     def __str__(self):
-        return f"{self.url} (ping {round(self.ping, 2)} ms)"
+        return f"Archive '{self.url}' (ping {round(self.ping, 2)} ms)"
 
     def clean(self, *args, **kwargs):
         super().clean(*args, **kwargs)
@@ -155,7 +155,7 @@ class Architecture(mini_buildd.models.base.Model):
     name = django.db.models.CharField(primary_key=True, max_length=50)
 
     def __str__(self):
-        return f"{self.name}"
+        return f"Architecture '{self.name}'"
 
 
 @functools.total_ordering
@@ -171,7 +171,7 @@ class Component(mini_buildd.models.base.Model):
     name = django.db.models.CharField(primary_key=True, max_length=50)
 
     def __str__(self):
-        return str(self.name)
+        return f"Component '{self.name}'"
 
     __hash__ = mini_buildd.models.base.Model.__hash__
 
@@ -305,7 +305,7 @@ Some sources need some more care via ``Extra options``, see below.
                                          codename__regex=r"^[a-z]+$").exclude(codename="experimental")
 
     def __str__(self):
-        return f"{self.origin} '{self.codename}' ({self.codeversion})"
+        return f"Source '{self.origin} {self.codename}' ({self.codeversion})"
 
     def mbd_release_file_values(self):
         """Compute a dict of values a matching release file must have."""
@@ -326,7 +326,7 @@ Some sources need some more care via ``Extra options``, see below.
         raise mini_buildd.HTTPBadRequest(f"{self}: No archive found (network down? ``Archive`` missing? ``Source`` with incorrect keys?)")
 
     def mbd_get_apt_line(self, limit_components=None):
-        components = [c for c in self.components.all() if limit_components is None or c in limit_components]
+        components = [c.name for c in self.components.all() if limit_components is None or c in limit_components]
         return mini_buildd.files.AptLine(self.mbd_get_archive().url,
                                          "",
                                          self.codename,
@@ -448,7 +448,7 @@ class PrioritySource(mini_buildd.models.base.Model):
         unique_together = ('source', 'priority')
 
     def __str__(self):
-        return f"{self.source} with prio={self.priority}"
+        return f"{self.source} with priority {self.priority}"
 
     def mbd_get_apt_preferences(self):
         return f"Package: *\nPin: {self.source.mbd_get_apt_pin()}\nPin-Priority: {self.priority}\n"
