@@ -45,27 +45,13 @@ import ssl
 import logging
 
 import twisted.internet.endpoints
+from twisted.internet import reactor
 
 import mini_buildd.config
 
 LOG = logging.getLogger(__name__)
 
 
-def reactor():
-    """
-    Get system's default twisted reactor.
-
-    Calling this function the very first time will select and initialize twisted's default reactor.
-    Consecutive calls will return the very same object again.
-
-    Note: Needed as long as damonize() functionality (as currently used in mini-buildd) breaks reactor if
-    run before this import.
-    """
-    from twisted.internet import reactor as _reactor
-    # LOG.debug(f"Twisted Reactor: {_reactor}: {id(_reactor)}")
-    return _reactor
-
-
 class TwistedEndpoint():
     @classmethod
     def _escape(cls, string):
@@ -104,6 +90,11 @@ class Endpoint(TwistedEndpoint):
     def _url_netloc(self, with_user=True, user=None):
         user = self._user if user is None else user
         host = self.options.get("host", self.options.get("interface", mini_buildd.config.HOSTNAME_FQDN))
+
+        # .. attention:: **compat** Old ':::<port>'-style notation
+        if host == "::":
+            host = mini_buildd.config.HOSTNAME_FQDN
+
         port = self.options.get("port")
         return (f"{user}@" if (user is not None and with_user) else "") + host + (f":{port}" if port else "")
 
@@ -128,8 +119,11 @@ class Endpoint(TwistedEndpoint):
     def hopo(self):
         return f"{self._url.hostname}:{self.options.get('port')}"
 
+    def scheme(self):
+        return self._url.scheme
+
     def geturl(self, with_user=False, user=None, path="", query=None):
-        return urllib.parse.ParseResult(scheme=self._url.scheme,
+        return urllib.parse.ParseResult(scheme=self.scheme(),
                                         netloc=self._url_netloc(with_user=with_user, user=user),
                                         path=path,
                                         params="",
@@ -166,7 +160,7 @@ class ServerEndpoint(Endpoint):
                 pass
             description = typ + self._opt("interface", _host) + self._opt("port", port)
 
-        twisted.internet.endpoints.serverFromString(reactor(), description)  # Syntax check only for now
+        twisted.internet.endpoints.serverFromString(reactor, description)  # Syntax check only for now
         super().__init__(description, protocol)
 
     def get_certificate(self):
@@ -215,7 +209,7 @@ class ClientEndpoint(Endpoint):
                 host, dummy, port = description.rpartition(":")
                 description = "tcp" + self._opt("host", host) + self._opt("port", port)
 
-        twisted.internet.endpoints.clientFromString(reactor(), description)  # Syntax check only for now
+        twisted.internet.endpoints.clientFromString(reactor, description)  # Syntax check only for now
         super().__init__(description, protocol)
         self.set_user(user)
 
@@ -232,7 +226,7 @@ class ClientEndpoint(Endpoint):
 
     def login(self, password):
         login_url = self.geturl(path=mini_buildd.config.URIS["accounts"]["login"].join())
-        next_url = self.geturl(path=mini_buildd.config.URIS["home"]["view"].join())
+        next_url = self.geturl(path=mini_buildd.config.URIS["accounts"]["null"].join())
 
         # Create cookie-enabled opener
         cookie_handler = urllib.request.HTTPCookieProcessor()
