@@ -3,16 +3,122 @@
 import os
 import shutil
 import threading
+import glob
 
 import logging
 
+import debian.debian_support
+
 import mini_buildd.dist
 import mini_buildd.call
+import mini_buildd.events
 
 LOG = logging.getLogger(__name__)
 
 _LOCKS = {}
 
+#: For doc/tests only
+LSBYCOMPONENT_EXAMPLE = """
+mbd-test-cpp | 20220530080821~test~SID+1 |           sid-test-unstable | main | source
+mbd-test-cpp | 20220530070229~test~SID+1 | sid-test-unstable-rollback0 | main | source
+"""
+
+
+class Ls(dict):
+    """
+    >>> ls = Ls("mbd-test-cpp", LSBYCOMPONENT_EXAMPLE)
+
+    >>> ls.rollbacks()
+    {'sid-test-unstable-rollback0': {'version': '20220530070229~test~SID+1', 'component': 'main', 'architecture': 'source'}}
+    >>> ls.filter(ls, diststr="sid-test-unstable")
+    {'sid-test-unstable': {'rollbacks': {'sid-test-unstable-rollback0': {'version': '20220530070229~test~SID+1', 'component': 'main', 'architecture': 'source'}}, 'version': '20220530080821~test~SID+1', 'component': 'main', 'architecture': 'source'}}
+    >>> ls.filter(ls.rollbacks(), version="20220530070229~test~SID+1")
+    {'sid-test-unstable-rollback0': {'version': '20220530070229~test~SID+1', 'component': 'main', 'architecture': 'source'}}
+    """
+
+    def __init__(self, source, ls_output, codenames=None, version=None, min_version=None):
+        super().__init__()
+        self.source = source
+
+        self.codenames = set()
+        for item in ls_output.split("\n"):
+            if item:
+                # reprepro lsbycomponent format: "<source> | <version> | <distribution> | <component> | <architecture>"
+                split = item.split("|")
+                dist = mini_buildd.dist.Dist(split[2].strip())
+                values = {
+                    "version": split[1].strip(),
+                    "component": split[3].strip(),
+                    "architecture": split[4].strip(),
+                }
+                if (codenames is None or dist.codename in codenames) and (not version or values["version"] == version) and (not min_version or debian.debian_support.Version(values["version"]) >= debian.debian_support.Version(min_version)):
+                    self.codenames.add(mini_buildd.dist.Codename(dist.codename))
+                    save_to = self.setdefault(dist.get(rollback=False), {"rollbacks": {}})
+                    if dist.is_rollback:
+                        save_to["rollbacks"][dist.get()] = values
+                    else:
+                        # Need to set individual items here to not possibly overwrite 'rollback'
+                        for k, v in values.items():
+                            save_to[k] = v
+
+        self.codenames = sorted(self.codenames)
+
+    def enrich(self):
+        for diststr in self:
+            ls = self[diststr]
+
+            repository, distribution, suite = mini_buildd.mdls().repository.parse_diststr(diststr)
+
+            if ls.get("version") is not None:
+                ls["dsc_path"] = repository.mbd_dsc_pool_path(self.source, ls["version"], raise_exception=False)
+
+                # Add changes files for convenience only - you can get to the changes files via 'events for this version' link
+                events_path = mini_buildd.config.ROUTES["events"].path
+                ls["changes_paths"] = [events_path.removeprefix(p) for p in glob.glob(events_path.join(self.source, ls.get("version"), "**", "*_source.changes"), recursive=True)]
+
+            ls["uploadable"] = suite.uploadable
+            if suite.migrates_to:
+                migrates_to = repository.mbd_get_diststr(distribution, suite.migrates_to)
+                ls["migrates_to"] = migrates_to
+                if ls.get("version") is not None:
+                    ls["is_migrated"] = bool(self.filter(diststr=migrates_to, version=ls["version"]))
+
+            for rollback_diststr in ls["rollbacks"]:
+                rollback_ls = ls["rollbacks"][rollback_diststr]
+                if rollback_ls.get("version") is not None:
+                    rollback_ls["dsc_path"] = repository.mbd_dsc_pool_path(self.source, rollback_ls["version"], raise_exception=False)
+
+    def rollbacks(self):
+        result = {}
+        for _v in self.values():
+            for d, v in _v["rollbacks"].items():
+                result[d] = v
+        return result
+
+    def filter(self, ls=None, diststr=None, version=None, raise_if_found="", raise_if_not_found=""):
+        if ls is None:
+            ls = self  # Non-rollback search
+
+        result = {}
+        for ls_diststr, ls_values in ls.items():
+            if ls_values.get("version") is not None and (diststr is None or ls_diststr == diststr) and (version is None or ls_values.get("version") == version):
+                result[ls_diststr] = ls_values
+        if result and raise_if_found:
+            raise mini_buildd.HTTPBadRequest(f"{raise_if_found}: Source '{self.source}_{version or 'any'}' found in '{diststr or 'any'}' distribution")
+        if not result and raise_if_not_found:
+            raise mini_buildd.HTTPBadRequest(f"{raise_if_not_found}: Source '{self.source}_{version or 'any'}' not found in '{diststr or 'any'}' distribution")
+        return result
+
+    def filter_rollbacks(self, **kwargs):
+        return self.filter(self.rollbacks(), **kwargs)
+
+    def filter_all(self, **kwargs):
+        return self.filter({**self, **self.rollbacks()}, **kwargs)
+
+    def changes(self, diststr, version, **kwargs):
+        values = self.filter(diststr=diststr, version=version, raise_if_not_found="Internal")[diststr]
+        return mini_buildd.changes.Changes({"Distribution": diststr, "Source": self.source, "Version": values["version"], "Architecture": "source", "Component": values["component"]}, **kwargs)
+
 
 class Reprepro():
     r"""
@@ -121,50 +227,8 @@ class Reprepro():
     def check(self):
         return self._call_locked(["check"])
 
-    def list(self, pattern, distribution, list_max=50):
-        result = []
-        for item in self._call_locked(["--list-format", "${package}|${$type}|${architecture}|${version}|${$source}|${$codename}|${$component};",
-                                       "--list-max", f"{list_max}"]
-                                      + ["listmatched",
-                                         distribution,
-                                         pattern]).split(";"):
-            if item:
-                item_split = item.split("|")
-                result.append({"package": item_split[0],
-                               "type": item_split[1],
-                               "architecture": item_split[2],
-                               "version": item_split[3],
-                               "source": item_split[4],
-                               "distribution": item_split[5],
-                               "component": item_split[6],
-                               })
-        return result
-
-    def ils(self, package, type_="dsc"):
-        # reprepro lsbycomponent format: "<source> | <version> | <distribution> | <component> | <architecture>"
-        for item in self._call_locked(["--type", type_, "lsbycomponent", package]).split("\n"):
-            if item:
-                item_split = item.split("|")
-                yield {
-                    "distribution": item_split[2].strip(),
-                    "source": item_split[0].strip(),
-                    "version": item_split[1].strip(),
-                    "component": item_split[3].strip(),
-                    "architecture": item_split[4].strip(),
-                }
-
-    @classmethod
-    def find_in(cls, ls, distribution=None, version=None):
-        for r in ls:
-            if (distribution is None or r["distribution"] == distribution) and (version is None or r["version"] == version):
-                return r
-        return None
-
-    def find(self, package, distribution=None, version=None):
-        p = self.find_in(self.ils(package), distribution, version)
-        if p is None:
-            raise mini_buildd.HTTPBadRequest(f"Package '{package}' ({version}) not found in '{distribution}'")
-        return p
+    def ls(self, source, **filter_options):
+        return Ls(source, self._call_locked(["--type", "dsc", "lsbycomponent", source]), **filter_options)
 
     def migrate(self, package, src_distribution, dst_distribution, version=None):
         return self._call_locked(["copysrc", dst_distribution, src_distribution, package] + ([version] if version else []))
