@@ -1,4 +1,5 @@
 import os
+import time
 import re
 import subprocess
 import logging
@@ -441,6 +442,7 @@ class SBuild():
                                                 "DEB_BUILD_PROFILES": self.breq.cget("Deb-Build-Profiles", "")}),
                 stdout=buildlog,
                 stderr=subprocess.STDOUT) as self.call:
+            LOG.info(f"Building {self.breq} (sbuild process '{self.call.pid}')...")
             retval = self.call.wait()
 
         # Update bres from buildlog
@@ -458,5 +460,15 @@ class SBuild():
 
     def cancel(self):
         if self.call is not None:
-            LOG.info(f"Terminating sbuild process for {self.breq}...")
+            LOG.info(f"Terminating {self.breq} (sbuild process '{self.call.pid}')...")
             self.call.terminate()
+
+            # Wait some time (max 6 seconds) to see if terminate() succeeds
+            for i in range(4):
+                time.sleep(i)
+                if self.call.poll() is not None:
+                    return
+
+            # I guess we should kill, then
+            LOG.warning(f"Killing {self.breq} (sbuild process '{self.call.pid}')...")
+            self.call.kill()
