@@ -21,7 +21,7 @@ class Session():
         """
         Close session (including retries on failure).
 
-        .. error:: **stale schroot sessions**: 'target is busy' on session close (stale schroot sessions).
+        .. attention:: **stale schroot sessions**: 'target is busy' on session close (stale schroot sessions).
 
            Occasionally, a schroot session can't be closed
            properly, leaving stale sessions around. Presumably,
