@@ -6,7 +6,7 @@ import django.conf.urls
 
 from mini_buildd.config import URIS, Uri
 import mini_buildd.admin
-from mini_buildd.views import DefaultView, DirView, EventsView, BuildsView, RepositoriesView, BuildersView, APIView, SetupView, LogView, AccountRegisterView, AccountActivateView, AccountProfileView, ExceptionMiddleware
+from mini_buildd.views import DefaultView, HomeView, DirView, EventsView, BuildsView, RepositoriesView, BuildersView, APIView, ManualView, SetupView, LogView, AccountRegisterView, AccountActivateView, AccountProfileView, AccountNullView, ExceptionMiddleware
 
 LOG = logging.getLogger(__name__)
 
@@ -15,11 +15,10 @@ def mbd_path(route, uri="view", view_cls=DefaultView):
     uri_obj = URIS[route][uri]
     name = route if uri == "view" else f"{route}-{uri}"
     path_func = re_path if uri_obj.django_with_path else path
-    LOG.info(f"Adding url: {name} -> {uri_obj}")
+    LOG.debug(f"Adding url: {name} -> {uri_obj}")
     return path_func(uri_obj.django(), view_cls.as_view(), kwargs={"route": route, "name": name}, name=name)
 
 
-# pylint: disable=invalid-name
 urlpatterns = [
     # Redirect
     path("", django.views.generic.base.RedirectView.as_view(url=URIS["home"]["view"].django())),
@@ -31,10 +30,11 @@ urlpatterns = [
     path(URIS["accounts"]["register"].django(), AccountRegisterView.as_view(), name="register"),
     path(URIS["accounts"]["activate"].django() + "<uidb64>/<token>/", AccountActivateView.as_view(), name="activate"),
     path(URIS["accounts"]["profile"].django(), AccountProfileView.as_view(), name="profile"),
+    path(URIS["accounts"]["null"].django(), AccountNullView.as_view(), name="null"),
     path(URIS["accounts"]["base"].django(), include("django.contrib.auth.urls")),
 
     # /mini_buildd/
-    mbd_path("home"),
+    mbd_path("home", view_cls=HomeView),
     mbd_path("events", view_cls=EventsView),
     mbd_path("events", uri="dir", view_cls=DirView),
     mbd_path("builds", view_cls=BuildsView),
@@ -45,7 +45,7 @@ urlpatterns = [
     mbd_path("crontab"),
     mbd_path("api"),
     mbd_path("sitemap"),
-    mbd_path("manual"),
+    mbd_path("manual", view_cls=ManualView),
     mbd_path("setup", view_cls=SetupView),
     mbd_path("log", view_cls=LogView),
 ]
@@ -53,7 +53,7 @@ urlpatterns = [
 # /mini_buildd/api/<call>/
 for _NAME, _CALL in mini_buildd.api.CALLS.items():
     _URI = Uri(_CALL.uri())
-    LOG.info(f"Adding API route: {_NAME}: {_URI}")
+    LOG.debug(f"Adding API route: {_NAME}: {_URI}")
     urlpatterns.append(path(_URI.django(), APIView.as_view(), kwargs={"call": _CALL}, name=f"apicall_{_NAME}"))
 
 django.conf.urls.handler400 = ExceptionMiddleware.bad_request
